PAWpySeed: pawpyseed.analysis.prep Namespace Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Namespace Members

Variables
pawpyseed.analysis.prep Namespace Reference

## Variables
list | filenames
list | names
| dpaths
list | defects = ["vac_1_Si", "sub_1_B_on_Si", "sub_1_P_on_Si", "sub_1_Cu_on_Si", "sub_1_S_on_Si"]
list | mathnames
list | charges = [[-2,-1,0,1,2], [-1,0], [0,1], [-1,0,1], [-2,-1,0,1,2,3]]
list | titles = []
string | my_dir = '/home/kyle/Research/projects/researchpapers/pawpyseed/thesis/results/projections'
| f = open('bandedges2.json', 'r')
| bandedges = yaml.load(f)
| be = bandedges[dp]
| bc = BulkCharacter.from_yaml(fname)
| efermi
| vbm
| cbm
| name
| spinpol
| True
| title

## Variable Documentation

pawpyseed.analysis.prep.bandedges = yaml.load(f)

pawpyseed.analysis.prep.bc = BulkCharacter.from_yaml(fname)

pawpyseed.analysis.prep.be = bandedges[dp]

pawpyseed.analysis.prep.cbm

list pawpyseed.analysis.prep.charges = [[-2,-1,0,1,2], [-1,0], [0,1], [-1,0,1], [-2,-1,0,1,2,3]]

list pawpyseed.analysis.prep.defects = ["vac_1_Si", "sub_1_B_on_Si", "sub_1_P_on_Si", "sub_1_Cu_on_Si", "sub_1_S_on_Si"]

pawpyseed.analysis.prep.dpaths

pawpyseed.analysis.prep.efermi

pawpyseed.analysis.prep.f = open('bandedges2.json', 'r')

list pawpyseed.analysis.prep.filenames

Initial value:
1 = ['../bcfres__%s.yaml' % s for s in ['Bcharge_-1', 'Bcharge_0', 'Pcharge_0', 'Pcharge_1',\
2 'charge_-2', 'charge_-1', 'charge_0', 'charge_1', 'charge_2']]

list pawpyseed.analysis.prep.mathnames

Initial value:
1 = ["$\\mathrm{Vac}_{\\mathrm{Si}}$", "$\\mathrm{B}_\\{mathrm{Si}}$", "$\\mathrm{P}_{\\mathrm{Si}}$",\
2 "$\\rm{Cu}_{\\rm{Si}}$", "$\\rm{S}_{\\rm{Si}}$"]

string pawpyseed.analysis.prep.my_dir = '/home/kyle/Research/projects/researchpapers/pawpyseed/thesis/results/projections'

pawpyseed.analysis.prep.name

pawpyseed.analysis.prep.names

Initial value:
1 = ['B substitutional -1', 'B substitutional 0', 'P substitutional 0',\
2 'P substitutional +1', 'vacancy -2', 'vacancy -1', 'vacancy 0',
3 'vacancy +1', 'vacancy +2']

pawpyseed.analysis.prep.spinpol

pawpyseed.analysis.prep.title

list pawpyseed.analysis.prep.titles = []

pawpyseed.analysis.prep.True

pawpyseed.analysis.prep.vbm